%global drv_vendor OVN
%global pkgname networking-ovn
%global srcname networking_ovn
%global docpath doc/build/html

%{!?upstream_version: %global upstream_version %{version}%{?milestone}}

Name:           python-%{pkgname}
Version:        4.0.2
Release:        2%{?dist}
Summary:        %{drv_vendor} OpenStack Neutron driver

License:        ASL 2.0
URL:            https://pypi.python.org/pypi/%{pkgname}
Source0:        https://tarballs.openstack.org/%{pkgname}/%{pkgname}-%{upstream_version}.tar.gz
Source1:        networking-ovn-metadata-agent.service
# patches_ignore=DROP-IN-RPM
# patches_base=4.0.2
Patch0001: 0001-Set-ovsdb-probe-interval-to-1-minute-on-the-client-s.patch
Patch0002: 0002-Fix-Router-port-always-marked-as-DOWN.patch
Patch0003: 0003-Add-default-dns_server-option-in-DHCP_Options-table.patch
Patch0004: 0004-Imported-Translations-from-Zanata.patch
Patch0005: 0005-Fix-error-in-router-port-maintenance-code.patch
Patch0006: 0006-Maintenance-Add-functional-tests-for-database-sync-t.patch
Patch0007: 0007-Fix-test_models_sync-functional-test.patch

BuildArch:      noarch
BuildRequires:  git
BuildRequires:  python2-devel
BuildRequires:  python2-debtcollector
BuildRequires:  python2-mock
BuildRequires:  openstack-macros

# This is required to generate the networking-ovn.ini configuration file
BuildRequires:  python-neutron

BuildRequires:  python2-oslo-config
BuildRequires:  python2-oslo-log
BuildRequires:  python2-openstackdocstheme
BuildRequires:  python2-ovsdbapp
BuildRequires:  python2-pbr
BuildRequires:  python2-sphinx


# python-openvswitch is not included in openstack-neutron-common.
# Its needed by networking-ovn.
Requires:       openstack-neutron-common
Requires:       python2-babel
Requires:       python2-futurist >= 1.2.0
Requires:       python2-netaddr
Requires:       python2-neutron-lib >= 1.13.0
Requires:       python2-oslo-config >= 2:5.1.0
Requires:       python-openvswitch >= 2.8.0
Requires:       python2-pbr
Requires:       python2-six
Requires:       python2-tenacity
Requires:       python2-ovsdbapp >= 0.8.0
Requires:       python2-pyOpenSSL >= 16.2.0

%description
OVN provides virtual networking for Open vSwitch and is a component of the
Open vSwitch project.

This package contains %{drv_vendor} networking driver which provides
integration between OpenStack Neutron and OVN.


%package metadata-agent
Summary:        networking-ovn metadata agent
BuildRequires:  systemd
Requires:       python-%{pkgname} = %{version}-%{release}
Requires:       openvswitch >= 2.8.0
%{?systemd_requires}

%description metadata-agent
OVN provides virtual networking for Open vSwitch and is a component of the
Open vSwitch project.

This package contains the agent that implements the metadata proxy so that VM's
can retrieve metadata from OpenStack Nova.

%prep
%autosetup -n %{pkgname}-%{upstream_version} -S git

# Let's handle dependencies ourselves
%py_req_cleanup

# Kill egg-info in order to generate new SOURCES.txt
rm -rf {srcname}.egg-info


%build
export SKIP_PIP_INSTALL=1
%{__python2} setup.py build
%{__python2} setup.py build_sphinx
rm -rf %{docpath}/.{doctrees,buildinfo}

# Generate config file
PYTHONPATH=. oslo-config-generator --namespace networking_ovn --output-file networking-ovn.ini
PYTHONPATH=. oslo-config-generator --namespace networking_ovn.metadata.agent --output-file networking-ovn-metadata-agent.ini


%install
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}

# Remove unused files
rm -rf %{buildroot}%{python2_sitelib}/bin
rm -rf %{buildroot}%{python2_sitelib}/doc
rm -rf %{buildroot}%{python2_sitelib}/tools


# Move config file to proper location
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron/plugins/networking-ovn
mv networking-ovn.ini %{buildroot}%{_sysconfdir}/neutron/plugins/networking-ovn
mv networking-ovn-metadata-agent.ini %{buildroot}%{_sysconfdir}/neutron/plugins/networking-ovn
chmod 640 %{buildroot}%{_sysconfdir}/neutron/plugins/*/*.ini

# Create configuration directories for all services that can be populated by users with custom *.conf files
mkdir -p %{buildroot}/%{_sysconfdir}/neutron/conf.d/networking-ovn-metadata-agent

# Install systemd units
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/networking-ovn-metadata-agent.service

%post metadata-agent
%systemd_post networking-ovn-metadata-agent.service


%preun metadata-agent
%systemd_preun networking-ovn-metadata-agent.service


%postun metadata-agent
%systemd_postun_with_restart networking-ovn-metadata-agent.service

%files
%license LICENSE
%doc %{docpath}
%{python2_sitelib}/%{srcname}
%{python2_sitelib}/%{srcname}-*.egg-info
%{_bindir}/neutron-ovn-db-sync-util
%dir %{_sysconfdir}/neutron/plugins/networking-ovn
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/plugins/networking-ovn/networking-ovn.ini

%files metadata-agent
%license LICENSE
%{_bindir}/networking-ovn-metadata-agent
%{_unitdir}/networking-ovn-metadata-agent.service
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini
%dir %{_sysconfdir}/neutron/conf.d/networking-ovn-metadata-agent

%changelog
* Tue Jul 24 2018 Jon Schlueter <jschluet@redhat.com> 4.0.2-2
- Fix: Router port always marked as DOWN (rhbz#1593755)
- Update to 4.0.2 (rhbz#1607993)
- Fix test_models_sync() functional test (rhbz#1564912)

* Thu Jul 05 2018 Jon Schlueter <jschluet@redhat.com> 4.0.1-3
- Strip the trailing '.' from the fqdn dns record stored in OVN NB DB (rhbz#1581332)
- bump to 4.0.1 tarball

* Tue Jul 03 2018 Daniel Alvarez <dalvarez@redhat.com> 4.0.1-0.20180420150812.c7c16d4
- Set ovsdb probe interval to 1 minute on the client side (rhbz#1578312)

* Thu Jun 28 2018 Numan Siddique <nusiddiq@redhat.com> 4.0.1-0.20180420150811.c7c16d4
- Fix error in router port maintenance code (rhbz#1593755)
- Add default dns_server option in DHCP_Options table (rhbz#1582512)
- Fix test_models_sync() functional test (rhbz#1433533)
- Maintenance: Add functional tests for database sync task (rhbz#1433533)

* Mon May 14 2018 Daniel Alvarez <dalvarez@redhat.com> 4.0.1-0.20180420150810.c7c16d4
- Handle port's 'port_security_enabled' flag when adding ACLs (rhbz#1575843)

* Thu Apr 26 2018 Daniel Alvarez <dalvarez@redhat.com> 4.0.1-0.20180420150809.c7c16d4
- L3HA: Take priorities into account in least loaded scheduling (rhbz#1562731)
- Clear binding:host_id when a subport is removed from a trunk (rhbz#1563678)
- Do not use a transaction for get_logical_port_chassis_and_datapath() (rhbz#1552545)

* Wed Apr 25 2018 Jon Schlueter <jschluet@redhat.com> 4.0.1-0.20180420150808.c7c16d4
- maintain python-openvswitch Req

